@@ -5,8 +5,8 @@ from notebuild.shell import run_shell
 
 class ServerManage:
     def __init__(self):
-        self.manage_conf_path = "/notechats/supervisord.conf"
-        self.conf_dir = "/notechats/notebuild"
+        self.manage_conf_path = "/notechats/notebuild/supervisord.conf"
+        self.conf_dir = "/notechats/notebuild/conf"
 
     def init(self):
         run_shell(f"mkdir -p {self.conf_dir}")
